Changelog
=========

[0.0.3] - Februrary 23, 2025
----------------------------

- Debug messages removed.


[0.0.2] - January 11, 2025
--------------------------

- **Image comparison:** based trivial water leak detection plugged in. Simply compares
  the image agains the previous one, measures the diferences, and records the magnitude.
  If there is no leak then there should be periods where no changes are detected between
  record images.




[0.0.1] - January 5, 2025
-------------------------

- **First release:** 

